"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.App = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const root_scene_1 = require("./components/root-scene");
const package_json_1 = require("../package.json");
const summary_1 = require("./analystic/summary");
class App {
    logger;
    rootScene;
    constructor(logger, rootScene) {
        this.logger = logger;
        this.rootScene = rootScene;
        this.logger.log(`%s\t%s`, ansi_colors_1.default.yellow.bold(`${package_json_1.name}⚡️`), ansi_colors_1.default.gray.italic(`v${package_json_1.version}`));
        this.logger.log('');
        this.rootScene = new root_scene_1.RootScene(this.logger.clone('root-scene'));
    }
    async exec() {
        let summary;
        try {
            const file = process.argv[2];
            if (!file)
                return this.showHelp();
            const decryptedPassword = process.argv[3];
            summary = new summary_1.Summary(this.rootScene.logger);
            await this.rootScene.init({ path: file, password: decryptedPassword });
            await this.rootScene.exec();
        }
        finally {
            await this.rootScene.dispose();
            summary?.print();
        }
    }
    showHelp() {
        this.logger.log(`┌
  Usage: ezrun|r [file] [password]

  Arguments:
    file    \t\t Path of the scene file to run (required)
    password\t\t Password to decrypt the scene 

  Informations:
  ✔ Github project: https://github.com/doanthuanthanh88/ezrun 
  ✔ Npm package   : https://www.npmjs.com/package/ezrun
  ✔ Docker Image  : https://hub.docker.com/repository/docker/doanthuanthanh88/ezrun
└`);
    }
}
exports.App = App;
//# sourceMappingURL=app.js.map