"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElementBuilder = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const lodash_clonedeep_1 = __importDefault(require("lodash.clonedeep"));
const lodash_merge_1 = __importDefault(require("lodash.merge"));
const events_manager_1 = require("./../managers/events-manager");
const element_shadow_1 = require("./element-shadow");
const root_scene_1 = require("./root-scene");
class ElementBuilder {
    scene;
    elem;
    constructor(scene) {
        this.scene = scene;
    }
    logger(logger) {
        this.elem.logger = logger;
        return this;
    }
    tag(name) {
        this.elem.tag = name;
        return this;
    }
    parent(g) {
        this.elem.parent = g;
        return this;
    }
    element(ElementClazz, ...args) {
        if (!ElementClazz.prototype.$$clone) {
            (0, element_shadow_1.copyElementShadowPrototype)(ElementClazz.prototype);
        }
        this.elem = new ElementClazz(...args);
        this.elem.scene = this.scene;
        this.elem.rootScene = this.scene instanceof root_scene_1.RootScene ? this.scene : this.scene.rootScene;
        const init = this.elem.init || (() => { });
        this.elem.init = async function (elemProps) {
            events_manager_1.globalEvent.emit('element/init');
            if (elemProps && typeof elemProps === 'object' && !Array.isArray(elemProps)) {
                let { ignore, '<-': inheritKeys, '->': exposeKey, ...eProps } = elemProps;
                if (inheritKeys)
                    eProps = (0, lodash_merge_1.default)({}, this.$$extend(inheritKeys), eProps);
                if (exposeKey)
                    this.$$export(exposeKey, (0, lodash_clonedeep_1.default)(eProps));
                elemProps = eProps;
                if (elemProps.if !== undefined)
                    this.if = elemProps.if;
                if (elemProps.loop !== undefined)
                    this.loop = elemProps.loop;
                if (elemProps.async !== undefined)
                    this.async = elemProps.async;
                if (elemProps.ignoreError !== undefined)
                    this.ignoreError = elemProps.ignoreError;
                if (elemProps.log)
                    this.logger.setLevel(elemProps.log);
                if (ignore !== undefined)
                    this.ignore = ignore;
            }
            await init.call(this, elemProps);
            this.$$markElementNeedReplace();
        };
        const exec = this.elem.exec;
        this.elem.exec = async function (parentData) {
            this.parentData = parentData;
            try {
                events_manager_1.globalEvent.emit('element/exec');
                await this.evalPropsBeforeExec();
                this.title && this.logger.info(`%s`, this.title);
                this.setContextVarsString = this.execResult = await exec.call(this, parentData);
            }
            catch (err) {
                this.error = err;
                if (!this.ignoreError)
                    throw this.error;
                this.logger.debug(ansi_colors_1.default.yellow(`⚠️ ${this.error?.message || this.error}`));
            }
            await this.setVarsAfterExec();
            return this.execResult;
        };
        const dispose = this.elem.dispose || (() => { });
        this.elem.dispose = async function () {
            events_manager_1.globalEvent.emit('element/dispose');
            await dispose.call(this);
        };
        return this;
    }
    build() {
        return this.elem;
    }
}
exports.ElementBuilder = ElementBuilder;
//# sourceMappingURL=element-builder.js.map