"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExecSh = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const child_process_1 = require("child_process");
const file_remote_1 = require("../../libs/file-remote");
const file_temp_1 = require("../../libs/file-temp");
const element_shadow_1 = require("../element-shadow");
class ExecSh extends element_shadow_1.ElementShadow {
    #tmpFile;
    script;
    path;
    bin = '/bin/sh';
    async init(props) {
        if (typeof props === 'string') {
            this.script = props;
        }
        else {
            Object.assign(this, props);
        }
        this.#tmpFile = new file_temp_1.FileTemp();
    }
    async exec() {
        if (this.path) {
            const fileRemote = new file_remote_1.FileRemote(this.path, this.scene);
            this.script = await fileRemote.getTextContent();
        }
        if (!this.script)
            throw new Error('"script" or "path" is required');
        try {
            this.logger.debugBlock(true);
            await this.#tmpFile.create(this.script);
            const rs = await new Promise((resolve, reject) => {
                (0, child_process_1.execFile)(this.bin, [this.#tmpFile.file], { env: process.env, cwd: this.scene.curDir }, (err, stdout, stderr) => {
                    if (err)
                        return reject(err);
                    stdout && this.logger.debug(ansi_colors_1.default.gray(stdout));
                    stderr && this.logger.debug(ansi_colors_1.default.red(stderr));
                    resolve((stdout + '\r\n' + stderr).trim());
                });
            });
            return rs;
        }
        finally {
            this.logger.debugBlock(false);
        }
    }
    async dispose() {
        this.#tmpFile.remove();
    }
}
exports.ExecSh = ExecSh;
//# sourceMappingURL=exec-sh.js.map