"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Exec = void 0;
const child_process_1 = require("child_process");
const element_shadow_1 = require("../element-shadow");
class Exec extends element_shadow_1.ElementShadow {
    commands;
    async init(props) {
        if (Array.isArray(props)) {
            this.commands = props;
        }
        else {
            Object.assign(this, props);
        }
    }
    async exec() {
        try {
            this.logger.debugBlock(true);
            const rs = await new Promise((resolve, reject) => {
                this.logger.debug(`› %s`, this.commands.join(' '));
                const [bin, ...args] = this.commands;
                const c = (0, child_process_1.spawn)(bin, args, { env: process.env, cwd: this.scene.curDir });
                c.on('message', msg => {
                    this.logger.trace(msg);
                });
                c.on('close', (code, signal) => {
                    if (signal)
                        return reject(new Error(`Error code ${code}, signal: ${signal}`));
                    resolve({ code, signal });
                });
                c.on('error', reject);
            });
            return rs;
        }
        finally {
            this.logger.debugBlock(false);
        }
    }
}
exports.Exec = Exec;
//# sourceMappingURL=exec.js.map