"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Get = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const fs_1 = require("fs");
const file_1 = require("../../libs/file");
const format_1 = require("../../libs/format");
const logger_1 = require("../../libs/logger");
const progress_bar_1 = require("../../libs/progress-bar");
const web_1 = require("stream/web");
const head_1 = require("./head");
class Get extends head_1.Head {
    method = 'get';
    responseType = 'json';
    saveTo;
    async send(fetchOpts = {}) {
        if (this.saveTo) {
            this.responseType = 'pipe';
            this.saveTo = this.scene.getPath(this.saveTo);
        }
        this.prehandleHeaders();
        const rs = await fetch(this.fullURLQuery, {
            method: this.method,
            headers: this.headers,
            ...fetchOpts
        });
        const data = await this.getResponseData(rs);
        this.response = {
            ok: rs.ok,
            headers: this.getResponseHeader(rs),
            data,
            status: rs.status,
            statusText: rs.statusText,
        };
        return this.response;
    }
    async getResponseData(rs) {
        switch (this.responseType) {
            case 'none':
                return undefined;
            case 'json':
                return rs.json();
            case 'blob':
                return rs.blob();
            case 'buffer':
                return rs.arrayBuffer();
            case 'pipe':
                let bar;
                if (this.logger.is(logger_1.LoggerLevel.INFO)) {
                    const logger = this.logger.clone();
                    if (this.title)
                        logger.addIndent();
                    bar = new progress_bar_1.ProgressBar(logger);
                    await bar.init(ansi_colors_1.default.gray.dim('Connecting to server...'));
                    bar.start();
                }
                try {
                    const resp = await new Promise(async (resolve, reject) => {
                        const stream = (0, fs_1.createWriteStream)(this.saveTo, { autoClose: false, emitClose: false });
                        try {
                            stream.on('error', reject);
                            await rs.body.pipeTo(new web_1.WritableStream({
                                total: 0,
                                write(chunk) {
                                    if (bar) {
                                        this.total += chunk.byteLength;
                                        bar.update(ansi_colors_1.default.gray(`Downloading ${(0, format_1.formatNumber)(this.total / 1000, { maximumFractionDigits: 0 })} kbs | Rate: ${(0, format_1.formatNumber)(chunk.byteLength, { maximumFractionDigits: 0 })} bytes`));
                                    }
                                    return stream.write(chunk);
                                }
                            }));
                            stream.end(() => resolve(new file_1.File(this.saveTo, this.scene)));
                        }
                        catch (err) {
                            reject(err);
                        }
                    });
                    return resp;
                }
                finally {
                    bar?.stop();
                }
            default:
                return rs.text();
        }
    }
}
exports.Get = Get;
//# sourceMappingURL=get.js.map