"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Test = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const element_shadow_1 = require("../element-shadow");
const test_error_1 = require("./test-error");
class Test extends element_shadow_1.ElementShadow {
    defaultTestTitle;
    testTitle;
    check;
    script;
    ignoreVarsBeforeExec = ['script', 'defaultTestTitle'];
    async init(props) {
        if (typeof props === 'string') {
            this.check = props;
            this.defaultTestTitle = this.check || this.script;
        }
        else {
            const { title, ...eprops } = props;
            Object.assign(this, eprops);
            this.testTitle = title;
            if (!this.testTitle)
                this.defaultTestTitle = this.check || this.script;
        }
    }
    failed(description = '') {
        this.error = new test_error_1.TestError(description);
        throw this.error;
    }
    async exec() {
        try {
            if (this.check !== undefined) {
                const rs = this.check;
                if (!rs)
                    this.failed();
            }
            if (this.script) {
                try {
                    await this.callFunctionScript(this.script);
                }
                catch (err) {
                    this.failed(err.message);
                }
            }
            this.testTitle && this.logger.info(this.testTitle);
        }
        catch (err) {
            if (err !== this.error)
                throw err;
            this.logger.error(`%s\t%s`, this.testTitle || this.defaultTestTitle, ansi_colors_1.default.italic.gray(this.error.message));
        }
        finally {
            this.setContextVarsString = !this.error;
        }
        return this.setContextVarsString;
    }
}
exports.Test = Test;
//# sourceMappingURL=test.js.map