"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("../../testing");
const global_vars_1 = require("./global-vars");
let globalVars;
beforeEach(() => {
    testing_1.Testing.reset();
    globalVars = testing_1.Testing.newElement(global_vars_1.GlobalVars);
});
afterEach(async () => {
    await globalVars.dispose();
});
test('should set to global globalVars', async () => {
    try {
        await globalVars.init({
            string: 'foo',
            number: 1,
            boolean: true,
            object: {
                string: 'foo',
                number: 1,
                boolean: true,
            },
            array1: [1, '2', true],
            array2: [{
                    string: 'foo',
                    number: 1,
                    boolean: true,
                }]
        });
        expect(testing_1.Testing.globalVars.string).toBeUndefined();
        expect(testing_1.Testing.globalVars.number).toBeUndefined();
        expect(testing_1.Testing.globalVars.boolean).toBeUndefined();
        expect(testing_1.Testing.globalVars.object).toBeUndefined();
        expect(testing_1.Testing.globalVars.array1).toBeUndefined();
        expect(testing_1.Testing.globalVars.array2).toBeUndefined();
        await globalVars.exec();
        expect(testing_1.Testing.globalVars.string).toBe('foo');
        expect(testing_1.Testing.globalVars.number).toBe(1);
        expect(testing_1.Testing.globalVars.boolean).toBe(true);
        expect(testing_1.Testing.globalVars.object).toStrictEqual({
            string: 'foo',
            number: 1,
            boolean: true,
        });
        expect(testing_1.Testing.globalVars.array1).toStrictEqual([1, '2', true]);
        expect(testing_1.Testing.globalVars.array2).toStrictEqual([{
                string: 'foo',
                number: 1,
                boolean: true,
            }]);
    }
    finally {
        await globalVars.dispose();
    }
});
test('should eval value into globalVars', async () => {
    await globalVars.init({
        name: 'thanh'
    });
    await globalVars.exec();
    const test = testing_1.Testing.newElement(global_vars_1.GlobalVars);
    await test.init({
        hello: 'hello ${globalVars.name}'
    });
    await test.exec();
    await test.dispose();
    expect(testing_1.Testing.globalVars.hello).toBe('hello thanh');
});
//# sourceMappingURL=global-vars.spec.js.map