"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("../../testing");
const vars_1 = require("./vars");
let vars;
beforeEach(() => {
    testing_1.Testing.reset();
    vars = testing_1.Testing.newElement(vars_1.Vars);
});
afterEach(async () => {
    await vars.dispose();
});
test('should set to global vars', async () => {
    try {
        await vars.init({
            string: 'foo',
            number: 1,
            boolean: true,
            object: {
                string: 'foo',
                number: 1,
                boolean: true,
            },
            array1: [1, '2', true],
            array2: [{
                    string: 'foo',
                    number: 1,
                    boolean: true,
                }]
        });
        expect(testing_1.Testing.vars.string).toBeUndefined();
        expect(testing_1.Testing.vars.number).toBeUndefined();
        expect(testing_1.Testing.vars.boolean).toBeUndefined();
        expect(testing_1.Testing.vars.object).toBeUndefined();
        expect(testing_1.Testing.vars.array1).toBeUndefined();
        expect(testing_1.Testing.vars.array2).toBeUndefined();
        await vars.exec();
        expect(testing_1.Testing.vars.string).toBe('foo');
        expect(testing_1.Testing.vars.number).toBe(1);
        expect(testing_1.Testing.vars.boolean).toBe(true);
        expect(testing_1.Testing.vars.object).toStrictEqual({
            string: 'foo',
            number: 1,
            boolean: true,
        });
        expect(testing_1.Testing.vars.array1).toStrictEqual([1, '2', true]);
        expect(testing_1.Testing.vars.array2).toStrictEqual([{
                string: 'foo',
                number: 1,
                boolean: true,
            }]);
    }
    finally {
        await vars.dispose();
    }
});
test('should eval value into vars', async () => {
    await vars.init({
        name: 'thanh'
    });
    await vars.exec();
    const test = testing_1.Testing.newElement(vars_1.Vars);
    await test.init({
        hello: 'hello ${vars.name}'
    });
    await test.exec();
    await test.dispose();
    expect(testing_1.Testing.vars.hello).toBe('hello thanh');
});
//# sourceMappingURL=vars.spec.js.map