"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.View = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const logger_1 = require("../../libs/logger");
const util_1 = require("util");
const element_shadow_1 = require("../element-shadow");
class View extends element_shadow_1.ElementShadow {
    data;
    async init(props) {
        if (typeof props !== 'object') {
            this.data = props;
        }
        else {
            Object.assign(this, props);
        }
    }
    async exec() {
        if (this.logger.is(logger_1.LoggerLevel.INFO) && this.data) {
            const arr = new Array(this.logger.indent).fill(null);
            arr.forEach(() => console.group());
            this.print();
            arr.forEach(() => console.groupEnd());
        }
        return this.data;
    }
    print() {
        return this.logger.print(this.format(this.data));
    }
    chalkByType(o, str) {
        const type = typeof o;
        if (type === 'string')
            return ansi_colors_1.default.yellow.dim(str);
        if (type === 'boolean')
            return ansi_colors_1.default.red.dim(str);
        if (type === 'number')
            return ansi_colors_1.default.green.dim(str);
        return ansi_colors_1.default.white.dim(str);
    }
    prettyFormat(obj, ctype = '⋅', space = '') {
        if (!obj || typeof obj !== 'object')
            return (0, util_1.format)(space + '%j', obj);
        const mes = [];
        if (Array.isArray(obj)) {
            obj.forEach((o, i) => {
                if (typeof o === 'object') {
                    const c = Array.isArray(o) ? '[]☑' : '{} ';
                    mes.push((0, util_1.format)(ansi_colors_1.default.gray.dim(space.substring(0, space.length - 2) + `╎${ctype}`) + `${this.chalkByType(o, '%d')}: ${ansi_colors_1.default.blue(c[0] + c[1])}`, i));
                    mes.push(this.prettyFormat(o, c[2], space + '╎ '));
                }
                else {
                    mes.push((0, util_1.format)(ansi_colors_1.default.gray.dim(space.substring(0, space.length - 2) + `╎${ctype}`) + `${this.chalkByType(o, '%d')}: %o`, i, o));
                }
            });
        }
        else {
            for (const k in obj) {
                const o = obj[k];
                if (typeof obj[k] === 'object') {
                    const c = Array.isArray(o) ? '[]╴' : '{} ';
                    mes.push((0, util_1.format)(ansi_colors_1.default.gray.dim(space.substring(0, space.length - 2) + `╎${ctype}`) + `${this.chalkByType(o, '%s')}: ${ansi_colors_1.default.magenta(c[0] + c[1])}`, k));
                    mes.push(this.prettyFormat(o, c[2], space + '╎ '));
                }
                else {
                    mes.push((0, util_1.format)(ansi_colors_1.default.gray.dim(space.substring(0, space.length - 2) + `╎${ctype}`) + `${this.chalkByType(o, '%s')}: %o`, k, o));
                }
            }
        }
        return mes.join('\n');
    }
    format(data) {
        const txt = this.prettyFormat(data);
        return (0, util_1.format)('%s', txt);
    }
}
exports.View = View;
//# sourceMappingURL=view.js.map