"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isGetEvalExp = exports.getVars = exports.setVars = void 0;
const async_function_1 = require("./../libs/async-function");
async function setVars(varObj, vl, ctx, others) {
    if (!varObj)
        return;
    if (typeof varObj === 'string') {
        others.vars[varObj] = vl;
        return [varObj];
    }
    else {
        const keys = Object.keys(varObj);
        for (const k of keys) {
            others.vars[k] = await getVars(varObj[k], ctx, others);
        }
        return keys;
    }
}
exports.setVars = setVars;
async function getVars(str, ctx, others) {
    if (!str)
        return str;
    const evalExp = isGetEvalExp(str);
    switch (evalExp) {
        case String:
            str = `\`${str}\``;
            if (str[1] === '$' && str[str.length - 2] === '}') {
                str = str.replace(/^`\$\{([^\}]+)\}`$/, '$1');
            }
            const vl = await (0, async_function_1.callFunctionScript)(`return ${str}`, ctx, others);
            if (typeof vl === 'string' && vl.indexOf('${') !== -1) {
                return getVars(vl, ctx, others);
            }
            return vl;
        case Object:
            const obj = await evalObject(str, ctx, others);
            return obj;
        default:
            return str;
    }
}
exports.getVars = getVars;
function isGetEvalExp(vl) {
    if (!vl)
        return null;
    if (typeof vl === 'string') {
        if (vl.includes('${'))
            return String;
    }
    else if (typeof vl === 'object') {
        if (isGetEvalExp(JSON.stringify(vl)))
            return Object;
    }
    return null;
}
exports.isGetEvalExp = isGetEvalExp;
async function evalObject(obj, ctx, others) {
    if (Array.isArray(obj)) {
        const vl = await Promise.all(obj.map(o => getVars(o, ctx, others)));
        return vl;
    }
    for (const k of Object.keys(obj)) {
        obj[k] = await getVars(obj[k], ctx, others);
    }
    return obj;
}
//# sourceMappingURL=variable.js.map