"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("./../testing");
beforeEach(() => {
    testing_1.Testing.reset();
});
test('set value to a variable to global', async () => {
    expect(testing_1.Testing.vars.name).toBeUndefined();
    await testing_1.Testing.rootScene.setVars('name', 'thanh');
    expect(testing_1.Testing.vars.name).toBe('thanh');
});
test('set a map value to variable to global', async () => {
    expect(testing_1.Testing.vars.name).toBeUndefined();
    await testing_1.Testing.rootScene.setVars({
        name: '${this.name}'
    }, undefined, {
        name: 'thanh'
    });
    expect(testing_1.Testing.vars.name).toBe('thanh');
});
test('get value from a variable in global without context', async () => {
    testing_1.Testing.vars.name = 'thanh';
    const name = await testing_1.Testing.rootScene.getVars('${vars.name}');
    expect(name).toBe('thanh');
});
test('get value from a variable in global with context', async () => {
    testing_1.Testing.vars.name = 'thanh';
    const ctx = {
        sex: 'male'
    };
    const name = await testing_1.Testing.rootScene.getVars('${vars.name}', ctx);
    const sex = await testing_1.Testing.rootScene.getVars('${this.sex}', ctx);
    expect(name).toBe('thanh');
    expect(sex).toBe('male');
});
test('get value from a value which ref to another', async () => {
    testing_1.Testing.vars.last = 'doan';
    testing_1.Testing.vars.name = 'thanh ${vars.last}';
    const name = await testing_1.Testing.rootScene.getVars('${vars.name}');
    expect(name).toBe('thanh doan');
});
test('get map value', async () => {
    testing_1.Testing.vars.hobies = ['game', 'travel'];
    testing_1.Testing.vars.user = {
        name: 'thanh'
    };
    const { name, last, hobby } = await testing_1.Testing.rootScene.getVars({
        name: '${vars.user.name}',
        last: 'doan',
        hobby: ['bia', '${vars.hobies[1]}']
    });
    expect(name).toBe('thanh');
    expect(last).toBe('doan');
    expect(hobby).toStrictEqual(['bia', 'travel']);
});
//# sourceMappingURL=variables.spec.js.map